@@ -86,7 +86,7 @@ class API:
             HTTP request method (GET, POST, PUT, DELETE, etc).
         path : str
             Path (e.g. "/") of the route for the API.
-        func : func
+        func : function
             Function to execute when route is reached.
         *args, **kwargs
             Additional arguments passed to the ``fastapi.FastAPI.add_route`` method.
@@ -144,6 +144,82 @@ class API:
         for r in routes:
             self.add_route(**r)
 
+    def on(self, event, *args, **kwargs):
+        """
+        Decorator function for handling events.
+
+        Parameters
+        ----------
+        event : str
+            The event to handle. Currently supports ``startup`` (before starting) and ``shutdown`` (during shutdown).
+        *args, **kwargs
+            Additional arguments passed to the ``fastapi.FastAPI.add_event_handler`` method.
+
+        Author
+        ------
+        Richard Wen <rrwen.dev@gmail.com>
+
+        Example
+        -------
+        .. jupyter-execute::
+
+            from msdss_base_api.core import API
+            app = API()
+
+            @app.on("startup")
+            def before_startup():
+                print("This is run before startup.")
+            
+            @app.on("shutdown")
+            def during_shutdown():
+                print("This is run during shutdown.")
+
+            # Run the app with app.start()
+            # API is hosted at http://localhost:8000
+            # app.start()
+        """
+        def on_decorator(func):
+            self.on_event(event=event, func=func, *args, **kwargs)
+        return on_decorator
+    
+    def on_event(self, event, func, *args, **kwargs):
+        """
+        Handles API events using a custom function.
+
+        Parameters
+        ----------
+        event : str
+            The event to handle. Currently supports ``startup`` (before starting) and ``shutdown`` (during shutdown).
+        func : function
+            Function to execute when the event occurs.
+        *args, **kwargs
+            Additional arguments passed to the ``fastapi.FastAPI.add_event_handler`` method.
+
+        Author
+        ------
+        Richard Wen <rrwen.dev@gmail.com>
+
+        Example
+        -------
+        .. jupyter-execute::
+
+            from msdss_base_api.core import API
+            app = API()
+
+            def before_startup():
+                print("This is run before startup.")
+            app.on_event("startup", before_startup)
+
+            def during_shutdown():
+                print("This is run during shutdown.")
+            app.on_event("shutdown", during_shutdown)
+
+            # Run the app with app.start()
+            # API is hosted at http://localhost:8000
+            # app.start()
+        """
+        self.app.add_event_handler(event_type=event, func=func, *args, **kwargs)
+
     def start(self, host="127.0.0.1", port=8000, log_level="info", *args, **kwargs):
         """
         Starts a server to host the API.
@@ -157,7 +233,7 @@ class API:
         log_level : str
             Level of verbose messages to display and log.
         *args, **kwargs
-             Additional arguments passed to the ``uvicorn.run`` method.
+            Additional arguments passed to the ``uvicorn.run`` method.
 
         Author
         ------
